# Porthmeus
# 23.10.18

require(ggplot2)
require(reshape)
require(dplyr)
require(tibble)
require(extrafont)

# load data
df <- read.csv("Fig7b_SupFig14_data_headCounts.csv")

# help function for SEM
SEM <- function(x){
    # calculate the standard error of a given vector x
    return(sd(x)/sqrt(length(x)))
}

# reshape the data, that one gets the mean number of heads per polyp in one well

df2<- df %>% group_by(Treatment, Well, Time_point) %>% summarize(meanHeads = mean(Heads), sdHeads=sd(Heads), semHeads =SEM(Heads))

# normalize the data for so that each timepoint is the fraction of average heads per well from the initial head number of the starting polyp

initials <- df %>% filter(Time_point==0)

corrected <- rep(0, nrow(df))
for(i in 1:nrow(df)){
    treat <- as.character(df[[i,"Treatment"]])
    well <- as.character(df[[i,"Well"]])
    ini <- initials %>% filter(Treatment == treat, Well == well)
    corrected[i] <- df[[i,"Heads"]]/ini[["Heads"]]
}

df <- add_column(df, fractionHeads= corrected)
# summarize once more
df3 <- df %>% group_by(Treatment, Time_point) %>% summarize(meanHeads= mean(fractionHeads), sdHeads=sd(fractionHeads), semHeads =SEM(fractionHeads))
df4 <- df  %>% group_by(Treatment, Time_point) %>% summarize(meanHeads= mean(Heads),sdHeads = sd(Heads), semHeads=SEM(Heads),number=n()/12, sumHeads=sum(Heads))
df5 <- df %>% group_by(Treatment, Time_point, Well) %>% summarize(number=n())
tmp <- df5 %>% group_by(Treatment,Time_point) %>% summarize(semNumber = SEM(number))
df4 <- inner_join(df4, tmp)
# plot the results

# define colors
cols <- c("DMSO"="yellow", "K02288 2uM"="green3")
colScale <- scale_color_manual(values=cols, name="Treatment")
fillScale <- scale_fill_manual(values=cols, name="Treatment")

# the number of heads per treatment and time point
pHeads <- ggplot(df4, aes(x=Time_point, y=meanHeads, color=Treatment, fill=Treatment)) +
        geom_line() +
        colScale +
        fillScale +
        geom_ribbon(aes(ymin=meanHeads-semHeads, ymax=meanHeads+semHeads), alpha=0.3) +
        geom_boxplot(data=df, aes(y=Heads, group=paste(Treatment,Time_point)),color="black", alpha=0.5, outlier.shape=21) +
        theme_linedraw() +
        theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
        ylab("No. of heads per polyp") +
        xlab("Time [d]")

glmHeads <- glm(data=df4, meanHeads ~ Time_point + Treatment + Time_point:Treatment)

pHeadSum <-  ggplot(df4, aes(x=Time_point, y=sumHeads, color=Treatment, fill=Treatment)) +
        geom_line() +
        colScale +
        fillScale +
        #geom_ribbon(aes(ymin=meanHeads-semHeads, ymax=meanHeads+semHeads), alpha=0.3) +
        #geom_boxplot(data=df, aes(y=Heads, group=paste(Treatment,Time_point)),color="black", alpha=0.5, outlier.shape=21) +
        theme_linedraw() +
        theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
        ylab("Total heads") +
        xlab("Time [d]")

pNumber <- ggplot(df4, aes(x=Time_point, y=number, color=Treatment, fill=Treatment)) +
        geom_line() +
        colScale +
        fillScale +
        geom_ribbon(aes(ymin=number-semNumber, ymax=number+semNumber), alpha=0.3) +
        geom_boxplot(data=df5, aes(y=number, group=paste(Treatment,Time_point)),color="black", alpha=0.5, outlier.shape=21) +
        theme_linedraw() +
        theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
        ylab("No. of polyps per well") +
        xlab("Time [d]")
glmNumber <- glm(data=df4, number ~ Time_point + Treatment + Time_point:Treatment)

ppCombined <- ggplot(df3, aes(x=Time_point, y=meanHeads, color=Treatment, fill=Treatment)) + 
            geom_line() +
            colScale +
            fillScale +
            geom_ribbon(aes(ymin=meanHeads-semHeads, ymax=meanHeads+semHeads), alpha=0.3) +
            geom_boxplot(data=df, aes(y=fractionHeads, group=paste(Treatment,Time_point)),color="black", alpha=0.5, outlier.shape=21) +
            theme_linedraw() +
            theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
            ylab("Fraction of heads per polyp") +
            xlab("Time [d]")

glmCombined <- glm(data=df3, meanHeads ~ Time_point + Treatment + Time_point:Treatment)

pdf("SupFig14_plot_HeadPlots.pdf", width=4, height=2, family="Arial")
print(pHeads)
print(pNumber)
print(pHeadSum)
print(ppCombined)
dev.off()

# create a simple boxplot of heads per polyp on day 0 and day 20 to show in the main figure
df_s <- df[df[["Time_point"]]==0 | df[["Time_point"]]==20,]
df_s[["TreatmentTime"]] <- factor(paste(df_s[["Treatment"]], df_s[["Time_point"]]), levels=c("DMSO 0", "K02288 2uM 0","DMSO 20", "K02288 2uM 20"))
print("Heads at day 0")
print(wilcox.test(data=df_s[df_s[["Time_point"]] == 0,], Heads~Treatment))
print("Heads at day 20")
print(wilcox.test(data=df_s[df_s[["Time_point"]] == 20,], Heads~Treatment))

mE <- max(df_s[["Heads"]])

pdf("Fig7b_plot_HeadPlots.pdf", width=3, height=2, family="Arial")
par(bty="n", mar=c(2,4,1,0.5))
boxplot(data=df_s, Heads~TreatmentTime, col=cols, ylim=c(0,mE*1.2), ylab="No. of heads per polyp")
points(c(1,2), c(mE,mE), type="l")
points(c(3,4), c(mE,mE)*1.1, type="l")
text(1.5,mE*1.1, "n.s.")
text(3.5, mE*1.2, "***", cex=1.5)
dev.off()
